class TaskFields:
    ID = "id"
    Title = "content"
    Item = "item"
    Labels = "labels"
    ProjectID = "project_id"
    Due = "due"

class Due:
    Date = "date"

class ProjectFields:
    Project = "project"
    Name = "name"


class LabelFields:
    Label = "label"
    Name = "name"
